==> jc-1.4.0.tar.gz: java/lang/VMDouble.h <==
// final class java.lang.VMDouble

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 63b94744942b946b java_lang_VMDouble

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMDouble_H_
#define _JC_java_lang_VMDouble_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_VMDouble$sub_refs	_jc_java_lang_VMDouble$sub_refs;
typedef struct _jc_java_lang_VMDouble$sub_nonrefs	_jc_java_lang_VMDouble$sub_nonrefs;
typedef struct _jc_java_lang_VMDouble$refs	_jc_java_lang_VMDouble$refs;
typedef struct _jc_java_lang_VMDouble$nonrefs	_jc_java_lang_VMDouble$nonrefs;
typedef struct _jc_java_lang_VMDouble$object	_jc_java_lang_VMDouble$object;

typedef const struct _jc_java_lang_VMDouble$vmethods	_jc_java_lang_VMDouble$vmethods;
typedef const struct _jc_java_lang_VMDouble$vtable	_jc_java_lang_VMDouble$vtable;
typedef const struct _jc_java_lang_VMDouble$vtype	_jc_java_lang_VMDouble$vtype;

// Constructors
extern void _jc_java_lang_VMDouble$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMDouble$object *);

// Static methods
extern void _jc_java_lang_VMDouble$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jlong _jc_java_lang_VMDouble$method$doubleToLongBits$9027e7a7fafba576(_jc_env *, jdouble);
extern jlong _jc_java_lang_VMDouble$method$doubleToRawLongBits$63dd0984b39af93a(_jc_env *, jdouble);
extern jdouble _jc_java_lang_VMDouble$method$longBitsToDouble$98edc49cf5e749a2(_jc_env *, jlong);

// Virtual methods structure
struct _jc_java_lang_VMDouble$vmethods {
};

// Vtable
struct _jc_java_lang_VMDouble$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMDouble$vmethods	java_lang_VMDouble;
};

// Vtype
struct _jc_java_lang_VMDouble$vtype {
	_jc_type			type;
	_jc_java_lang_VMDouble$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMDouble$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMDouble$refs {
    _jc_java_lang_VMDouble$sub_refs	java_lang_VMDouble;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMDouble$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMDouble$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMDouble$sub_nonrefs	java_lang_VMDouble;
};

// Object instance structure
struct _jc_java_lang_VMDouble$object {
	_jc_java_lang_VMDouble$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMDouble$vtype	*vtype;
	_jc_java_lang_VMDouble$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMDouble$vtype _jc_java_lang_VMDouble$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMDouble, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMDouble$class_object;

#endif	/* _JC_java_lang_VMDouble_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMDouble.h <==
// final class java.lang.VMDouble

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 43adbb439e3f2be3 java_lang_VMDouble

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMDouble_H_
#define _JC_java_lang_VMDouble_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VMDouble$sub_refs	_jc_java_lang_VMDouble$sub_refs;
typedef struct _jc_java_lang_VMDouble$sub_nonrefs	_jc_java_lang_VMDouble$sub_nonrefs;
typedef struct _jc_java_lang_VMDouble$refs	_jc_java_lang_VMDouble$refs;
typedef struct _jc_java_lang_VMDouble$nonrefs	_jc_java_lang_VMDouble$nonrefs;
typedef struct _jc_java_lang_VMDouble$object	_jc_java_lang_VMDouble$object;

typedef const struct _jc_java_lang_VMDouble$vmethods	_jc_java_lang_VMDouble$vmethods;
typedef const struct _jc_java_lang_VMDouble$vtable	_jc_java_lang_VMDouble$vtable;
typedef const struct _jc_java_lang_VMDouble$vtype	_jc_java_lang_VMDouble$vtype;

// Constructors
extern void _jc_java_lang_VMDouble$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMDouble$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_lang_VMDouble$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jlong _jc_java_lang_VMDouble$method$doubleToLongBits$9027e7a7fafba576(_jc_env *, jdouble) _JC_JCNI_ATTR;
extern jlong _jc_java_lang_VMDouble$method$doubleToRawLongBits$63dd0984b39af93a(_jc_env *, jdouble) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMDouble$method$initIDs$bf51eea2c3d791d5(_jc_env *) _JC_JCNI_ATTR;
extern jdouble _jc_java_lang_VMDouble$method$longBitsToDouble$98edc49cf5e749a2(_jc_env *, jlong) _JC_JCNI_ATTR;
extern jdouble _jc_java_lang_VMDouble$method$parseDouble$5527fdfc458363ba(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_VMDouble$method$toString$854f8a9e26dc66fd(_jc_env *, jdouble, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VMDouble$vmethods {
};

// Vtable
struct _jc_java_lang_VMDouble$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMDouble$vmethods	java_lang_VMDouble;
};

// Vtype
struct _jc_java_lang_VMDouble$vtype {
	_jc_type			type;
	_jc_java_lang_VMDouble$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMDouble$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMDouble$refs {
    _jc_java_lang_VMDouble$sub_refs	java_lang_VMDouble;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMDouble$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMDouble$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMDouble$sub_nonrefs	java_lang_VMDouble;
};

// Object instance structure
struct _jc_java_lang_VMDouble$object {
	_jc_java_lang_VMDouble$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMDouble$vtype	*vtype;
	_jc_java_lang_VMDouble$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMDouble$vtype _jc_java_lang_VMDouble$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMDouble, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMDouble$class_object;

#endif	/* _JC_java_lang_VMDouble_H_ */
